==> pyfusionenergy_1.0.1.zip: pyfusionenergy_1.0.1/prototypes/technologies/vanadium-processing.lua <==
local technology = {
    type = "technology",
    name = "vanadium-processing",
    icon = "__pyfusionenergy__/graphics/technology/vanadium-processing.png",
    icon_size = 128,
    order = "c-a",
    prerequisites = {"advanced-mining-facilities", "diamond-mining"},
    effects = {
        {
            type = "unlock-recipe",
            recipe = "plankton-farm"
        },
        {
            type = "unlock-recipe",
            recipe = "xyhiphoe-pool"
        },
        {
            type = "unlock-recipe",
            recipe = "phytoplankton"
        },
        {
            type = "unlock-recipe",
            recipe = "xyhiphoe-blood"
        },
        {
            type = "unlock-recipe",
            recipe = "xyhiphoe-hydrocyclone"
        },
        {
            type = "unlock-recipe",
            recipe = "vanabins"
        },
        {
            type = "unlock-recipe",
            recipe = "blue-liquor"
        },
        {
            type = "unlock-recipe",
            recipe = "vpulp1"
        },
        {
            type = "unlock-recipe",
            recipe = "vpulp2"
        },
        {
            type = "unlock-recipe",
            recipe = "vpulp3"
        },
        {
            type = "unlock-recipe",
            recipe = "vpulp4"
        },
        {
            type = "unlock-recipe",
            recipe = "vpulp5"
        },
        {
            type = "unlock-recipe",
            recipe = "vpulp-precip"
        },
        {
            type = "unlock-recipe",
            recipe = "pressured-vpulp"
        },
        {
            type = "unlock-recipe",
            recipe = "vanadates"
        },
        {
            type = "unlock-recipe",
            recipe = "vanadium-solution"
        },
        {
            type = "unlock-recipe",
            recipe = "vanadium-concentrate"
        },
        {
            type = "unlock-recipe",
            recipe = "organic-vanadate"
        },
        {
            type = "unlock-recipe",
            recipe = "cobalt-solvent"
        },
        {
            type = "unlock-recipe",
            recipe = "solvent-separation"
        },
        {
            type = "unlock-recipe",
            recipe = "acid-strip-solution"
        },
        {
            type = "unlock-recipe",
            recipe = "pregnant-solution"
        },
        {
            type = "unlock-recipe",
            recipe = "sodium-chlorate"
        },
        {
            type = "unlock-recipe",
            recipe = "vanadium-oxide"
        },
        {
            type = "unlock-recipe",
            recipe = "wastewater-filtration"
        },
        {
            type = "unlock-recipe",
            recipe = "wastewater-recovery"
        }
    },
    unit = {
        count = 30,
        ingredients = {
            {"science-pack-1", 2},
            {"science-pack-2", 2},
            {"science-pack-3", 1},
            {"production-science-pack", 1}
        },
        time = 70
    }
}
data:extend {technology}

==> pyfusionenergy_1.6.7.zip: pyfusionenergy_1.6.7/prototypes/technologies/vanadium-processing.lua <==
TECHNOLOGY {
    type = "technology",
    name = "vanadium-processing",
    icon = "__pyfusionenergygraphics__/graphics/technology/vanadium-processing.png",
    icon_size = 128,
    order = "c-a",
    prerequisites = {"advanced-mining-facilities"},
    effects = {
        {
            type = "unlock-recipe",
            recipe = "plankton-farm"
        },
        {
            type = "unlock-recipe",
            recipe = "xyhiphoe-pool-mk01"
        },
        {
            type = "unlock-recipe",
            recipe = "phytoplankton"
        },
        {
            type = "unlock-recipe",
            recipe = "xyhiphoe-blood"
        },
        {
            type = "unlock-recipe",
            recipe = "xyhiphoe-hydrocyclone"
        },
        {
            type = "unlock-recipe",
            recipe = "vanabins"
        },
        {
            type = "unlock-recipe",
            recipe = "blue-liquor"
        },
        {
            type = "unlock-recipe",
            recipe = "vpulp1"
        },
        {
            type = "unlock-recipe",
            recipe = "vpulp2"
        },
        {
            type = "unlock-recipe",
            recipe = "vpulp3"
        },
        {
            type = "unlock-recipe",
            recipe = "vpulp4"
        },
        {
            type = "unlock-recipe",
            recipe = "vpulp5"
        },
        {
            type = "unlock-recipe",
            recipe = "vpulp-precip"
        },
        {
            type = "unlock-recipe",
            recipe = "pressured-vpulp"
        },
        {
            type = "unlock-recipe",
            recipe = "vanadates"
        },
        {
            type = "unlock-recipe",
            recipe = "vanadium-solution"
        },
        {
            type = "unlock-recipe",
            recipe = "vanadium-concentrate"
        },
        {
            type = "unlock-recipe",
            recipe = "organic-vanadate"
        },
        {
            type = "unlock-recipe",
            recipe = "cobalt-solvent"
        },
        {
            type = "unlock-recipe",
            recipe = "solvent-separation"
        },
        {
            type = "unlock-recipe",
            recipe = "acid-strip-solution"
        },
        {
            type = "unlock-recipe",
            recipe = "pregnant-solution"
        },
        {
            type = "unlock-recipe",
            recipe = "sodium-chlorate"
        },
        {
            type = "unlock-recipe",
            recipe = "vanadium-oxide"
        },
        {
            type = "unlock-recipe",
            recipe = "wastewater-filtration"
        },
        {
            type = "unlock-recipe",
            recipe = "wastewater-recovery"
        }
    },
    unit = {
        count = 30,
        ingredients = {
            {"automation-science-pack", 2},
            {"logistic-science-pack", 2},
            {"chemical-science-pack", 1},
        },
        time = 70
    }
}
